package VMOMI::HostNumericSensorType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
